==> plasma-profile-1.2.3-sources.jar: org/plasma/sdo/profile/SDOKey.java <==
//==============================================================================
//                                                          
// This software artifact was generated using PlasmaSDO    
// provisioning tools.                                      
//                                                          
//==============================================================================
package org.plasma.sdo.profile;


import fUML.Syntax.Classes.Kernel.*;
import org.modeldriven.fuml.repository.ext.Stereotype;
import org.plasma.sdo.Key;
/**
* 
* This stereotype tags or annotates a UML property as representing some type of key within a data store, data transfer or transient storage medium.
* 
* @author Plasma-Team
* @version 1.2.3
*/
public class SDOKey extends Stereotype
    implements Key
{

    /**
    * Specifies the type of key
    */
    public static final String TYPE = "type";
    public static final String BASE__PROPERTY = "base_Property";
    /**
    * Links a property element which supplies the actual data for the key where multiple possible targets exist. Where a key property is a reference SDO property and the target entity has multiple primary keys, the supplier is used by services to disambiguate which target key actually supplies the data.
    */
    public static final String SUPPLIER = "supplier";

    /**
    * Specifies the type of key
    */
    private KeyType type;
    private Property base_Property;
    /**
    * Links a property element which supplies the actual data for the key where multiple possible targets exist. Where a key property is a reference SDO property and the target entity has multiple primary keys, the supplier is used by services to disambiguate which target key actually supplies the data.
    */
    private NamedElement supplier;


    public KeyType getType() {
        return this.type;
    }

    public void setType(KeyType value) {
        this.type = value;
    }

    public Property getBase_Property() {
        return this.base_Property;
    }

    public void setBase_Property(Property value) {
        this.base_Property = value;
    }

    public NamedElement getSupplier() {
        return this.supplier;
    }

    public void setSupplier(NamedElement value) {
        this.supplier = value;
    }
}

==> plasma-profile-1.2.4-sources.jar: org/plasma/sdo/profile/SDOKey.java <==
//==============================================================================
//                                                          
// This software artifact was generated using PlasmaSDO    
// provisioning tools.                                      
//                                                          
//==============================================================================
package org.plasma.sdo.profile;


import fUML.Syntax.Classes.Kernel.*;
import org.modeldriven.fuml.repository.ext.Stereotype;
import org.plasma.sdo.Key;
/**
* 
* This stereotype tags or annotates a UML property as representing some type of key within a data store, data transfer or transient storage medium.
* 
* @author Plasma-Team
* @version 1.2.4
*/
public class SDOKey extends Stereotype
    implements Key
{

    /**
    * Specifies the type of key
    */
    public static final String TYPE = "type";
    public static final String BASE__PROPERTY = "base_Property";
    /**
    * Links a property element which supplies the actual data for the key where multiple possible targets exist. Where a key property is a reference SDO property and the target entity has multiple primary keys, the supplier is used by services to disambiguate which target key actually supplies the data.
    */
    public static final String SUPPLIER = "supplier";
    /**
    * The key set or constraint name
    */
    public static final String GROUP = "group";
    /**
    * The position or ordering of a key within a group
    */
    public static final String SEQUENCE = "sequence";

    /**
    * Specifies the type of key
    */
    private KeyType type;
    private Property base_Property;
    /**
    * Links a property element which supplies the actual data for the key where multiple possible targets exist. Where a key property is a reference SDO property and the target entity has multiple primary keys, the supplier is used by services to disambiguate which target key actually supplies the data.
    */
    private NamedElement supplier;
    /**
    * The key set or constraint name
    */
    private String group;
    /**
    * The position or ordering of a key within a group
    */
    private Integer sequence;


    public KeyType getType() {
        return this.type;
    }

    public void setType(KeyType value) {
        this.type = value;
    }

    public Property getBase_Property() {
        return this.base_Property;
    }

    public void setBase_Property(Property value) {
        this.base_Property = value;
    }

    public NamedElement getSupplier() {
        return this.supplier;
    }

    public void setSupplier(NamedElement value) {
        this.supplier = value;
    }

    public String getGroup() {
        return this.group;
    }

    public void setGroup(String value) {
        this.group = value;
    }

    public Integer getSequence() {
        return this.sequence;
    }

    public void setSequence(Integer value) {
        this.sequence = value;
    }
}
